@@ -114,6 +114,9 @@ class Sound:
         except FileNotFoundError:
             logger.info(f"Custom audio not found: {self.sound_file}")
             self.beep_needed = True
+        except AttributeError:
+            logger.info(f"Custom audio not found: {self.sound_file}")
+            self.beep_needed = True
 
     def play_sound(self):
         if self.beep_needed is False:
@@ -338,6 +341,8 @@ def config_allocation(args, config, durations: Durations):
     logger.info(config.theme_color)
     display.theme = display.color_map(config.theme_color)
     logger.info(display.theme)
+    if args.audio_file:
+        config.audio_file = args.audio_file
     if args.work_time:
         durations.work.mins = args.work_time
         durations.work.secs = mins_to_secs(args.work_time)
@@ -350,8 +355,9 @@ def run(args, config):
     global is_speed_mode, timer_mode
 
     durations_data = Durations()
-
     config_allocation(args, config, durations_data)
+    sound = Sound(config.audio_file)
+    sound.initialise()
 
     if check_for_file(DATA_FILE_LOCATION) is False:
         virgin_boostrap()
@@ -359,23 +365,16 @@ def run(args, config):
     data_file.data_load_on_boot(durations_data)
 
     logger.info("Durations model set")
-    logger.info(f"Work time: {durations_data.work.mins}")
-    logger.info(f"Work time: {durations_data.work.secs}")
-    logger.info(f"Work time: {durations_data.rest.mins}")
-    logger.info(f"Work time: {durations_data.rest.secs}")
+    logger.info(f"Work time:    {durations_data.work.mins}")
+    logger.info(f"Work time:    {durations_data.work.secs}")
+    logger.info(f"Work time:    {durations_data.rest.mins}")
+    logger.info(f"Work time:    {durations_data.rest.secs}")
+    logger.info(f"Sound file:   {sound.sound_file}")
 
     if args.speed_mode is True:
         is_speed_mode = True
     logger.info(f"Speed mode set to {is_speed_mode}")
 
-    if args.audio_file:
-        sound = Sound(audio_path=args.audio_file)
-        logger.debug(f"Custom audio file path specified {sound}")
-    else:
-        sound = Sound()
-        logger.debug("Using default audio")
-    sound.initialise()
-    logger.debug("Sound initialised")
     sylo = Sylo(
         durations=durations_data,
         sound_obj=sound,
